==> gc-api-1.0-sources.jar: io/ultreia/gc/model/GcFieldNote.java <==
package io.ultreia.gc.model;

/*-
 * #%L
 * GC toolkit :: API
 * %%
 * Copyright (C) 2017 Ultreia.io
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

/**
 * Created by tchemit on 15/04/17.
 *
 * @author Tony Chemit - dev@tchemit.fr
 */
public class GcFieldNote {

    private final String name;
    private final String url;
    private final String composeUrl;
    private final String date;
    private final String logType;
    private boolean favorite;
    private boolean selected;

    public GcFieldNote(String name, String url, String composeUrl, String date, String logType) {
        this.name = name;
        this.url = url;
        this.composeUrl = composeUrl;
        this.date = date;
        this.logType = logType;
    }

    public String getDate() {
        return date;
    }

    public String getLogType() {
        return logType;
    }

    public String getName() {
        return name;
    }

    public String getUrl() {
        return url;
    }

    public boolean isFavorite() {
        return favorite;
    }

    public void setFavorite(boolean favorite) {
        this.favorite = favorite;
    }

    public String getComposeUrl() {
        return composeUrl;
    }

    public boolean isSelected() {
        return selected;
    }

    public void setSelected(boolean selected) {
        this.selected = selected;
    }

    @Override
    public String toString() {
        return String.format("%s - %s (%s)", name, date, logType);
    }
}

==> gc-api-1.1-sources.jar: io/ultreia/gc/model/GcFieldNote.java <==
package io.ultreia.gc.model;

/*-
 * #%L
 * GC toolkit :: API
 * %%
 * Copyright (C) 2017 Ultreia.io
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Optional;

/**
 * Created by tchemit on 15/04/17.
 *
 * @author Tony Chemit - dev@tchemit.fr
 */
public class GcFieldNote {

    private final String name;
    private final String url;
    private final String composeUrl;
    private final String date;
    private final String logType;
    private GcCacheImage image;
    private boolean favorite;
    private boolean selected;

    public GcFieldNote(String name, String url, String composeUrl, String date, String logType) {
        this.name = name;
        this.url = url;
        this.composeUrl = composeUrl;
        this.date = date;
        this.logType = logType;
    }

    public void setImage(GcCacheImage image) {
        this.image = image;
    }

    public Optional<GcCacheImage> getImage() {
        return Optional.ofNullable(image);
    }

    public String getDate() {
        return date;
    }

    public String getLogType() {
        return logType;
    }

    public String getName() {
        return name;
    }

    public String getUrl() {
        return url;
    }

    public boolean isFavorite() {
        return favorite;
    }

    public void setFavorite(boolean favorite) {
        this.favorite = favorite;
    }

    public String getComposeUrl() {
        return composeUrl;
    }

    public boolean isSelected() {
        return selected;
    }

    public void setSelected(boolean selected) {
        this.selected = selected;
    }

    @Override
    public String toString() {
        return String.format("%s - %s (%s)", name, date, logType);
    }

    public boolean withImage() {
        return image!=null;
    }
}
